/* 
 * Copyright (C) 2005  Network Applied Communication Laboratory Co., Ltd.
 *
 * This file is part of Rast.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 *
 * Linking the Rast statically or dynamically with other modules is
 * making a combined work based on the Rast.  Thus, the terms and
 * conditions of the GNU General Public License cover the whole
 * combination.
 *
 * As a special exception, the copyright holders of the Rast give
 * you permission to link the Rast with independent modules that
 * communicate with the Rast solely through the the Apache Portable
 * Runtime interface, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * combined work under terms of your choice, provided that every
 * copy of the combined work is accompanied by a complete copy of
 * the source code of the Rast (the version of the Rast used to
 * produce the combined work), being distributed under the terms of
 * the GNU General Public License plus this exception.  An
 * independent module is a module which is not derived from or based
 * on the Rast.
 *
 * Note that people who make modified versions of the Rast are not
 * obligated to grant this special exception for their modified
 * versions; it is their choice whether to do so.  The GNU General
 * Public License gives permission to release a modified version
 * without this exception; this exception also makes it possible to
 * release a modified version which carries forward this exception.
 */

#include <stdio.h>
#include <stdlib.h>

#include <apr_pools.h>

#include "rast/db.h"

static int memory_error(int retcode);
static void print_error(rast_error_t *error);

rast_property_t properties[] = {
    {
        "filename",
        RAST_TYPE_STRING,
        RAST_PROPERTY_FLAG_SEARCH | RAST_PROPERTY_FLAG_UNIQUE
    },
    {
        "title",
        RAST_TYPE_STRING,
        RAST_PROPERTY_FLAG_TEXT_SEARCH | RAST_PROPERTY_FLAG_FULL_TEXT_SEARCH
    },
    {
        "last_modified",
        RAST_TYPE_DATE,
        RAST_PROPERTY_FLAG_SEARCH
    },
    {
        "filesize",
        RAST_TYPE_UINT,
        RAST_PROPERTY_FLAG_SEARCH
    },
};

int
main(int argc, char **argv)
{
    apr_pool_t *pool;
    char *dbpath;
    rast_db_create_option_t *options;
    rast_error_t *error;

    if (argc < 2) {
        fprintf(stderr, "usage: %s <db>\n", argv[0]);
        return 1;
    }
    dbpath = argv[1];

    apr_initialize();
    atexit(apr_terminate);
    error = rast_initialize();
    if (error != RAST_OK) {
        print_error(error);
        return 1;
    }
    atexit(rast_finalize);

    apr_pool_create_ex(&pool, NULL, memory_error, NULL);

    options = rast_db_create_option_create(pool);
    options->preserve_text = 1;
    options->properties = properties;
    options->num_properties = 4;

    error = rast_db_create(dbpath, options, pool);
    if (error != RAST_OK) {
        print_error(error);
        return 1;
    }

    return 0;
}

static int
memory_error(int retcode)
{
    abort();
    return -1;  /* prevent compiler warnings */
}

static void
print_error(rast_error_t *error)
{
#ifdef RAST_DEBUG
    fprintf(stderr, "%s:%d: %s\n", error->file, error->line, error->message);
#else
    fprintf(stderr, "error: %s\n", error->message);
#endif
    rast_error_destroy(error);
}

/* vim: set filetype=c sw=4 expandtab : */
