/* 
 * Copyright (C) 2005  Network Applied Communication Laboratory Co., Ltd.
 *
 * This file is part of Rast.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 *
 * Linking the Rast statically or dynamically with other modules is
 * making a combined work based on the Rast.  Thus, the terms and
 * conditions of the GNU General Public License cover the whole
 * combination.
 *
 * As a special exception, the copyright holders of the Rast give
 * you permission to link the Rast with independent modules that
 * communicate with the Rast solely through the the Apache Portable
 * Runtime interface, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * combined work under terms of your choice, provided that every
 * copy of the combined work is accompanied by a complete copy of
 * the source code of the Rast (the version of the Rast used to
 * produce the combined work), being distributed under the terms of
 * the GNU General Public License plus this exception.  An
 * independent module is a module which is not derived from or based
 * on the Rast.
 *
 * Note that people who make modified versions of the Rast are not
 * obligated to grant this special exception for their modified
 * versions; it is their choice whether to do so.  The GNU General
 * Public License gives permission to release a modified version
 * without this exception; this exception also makes it possible to
 * release a modified version which carries forward this exception.
 */

#include <stdlib.h>

#include "rast/config.h"
#include "rast/rast.h"
#include "rast/encoding.h"

static int initialized = 0;
static apr_pool_t *global_pool = NULL;

static int
rast_abort(int retcode)
{
    abort();
    return -1;  /* prevent compiler warnings */
}

static apr_abortfunc_t abort_func = rast_abort;

void
rast_set_abort_func(apr_abortfunc_t func)
{
    abort_func = func;
}

apr_pool_t *
rast_pool_create(apr_pool_t *parent)
{
    apr_pool_t *pool;

    if (apr_pool_create_ex(&pool, NULL, abort_func, NULL) != APR_SUCCESS) {
        abort_func(APR_ENOMEM);
    }
    return pool;
}

rast_error_t *
rast_initialize()
{
    const char *dir;

    initialized++;
    if (initialized > 1) {
        return RAST_OK;
    }

    global_pool = rast_pool_create(NULL);

    dir = getenv("RAST_ENCODINGDIR");
    if (dir == NULL) {
        dir = RAST_ENCODINGDIR;
    }
    return rast_load_encoding_modules(dir);
}

void
rast_finalize()
{
    initialized--;
    if (initialized > 0) {
        return;
    }
    rast_unload_encoding_modules();
    apr_pool_destroy(global_pool);
    global_pool = NULL;
}

apr_pool_t *
rast_get_global_pool()
{
    return global_pool;
}

rast_search_option_t *
rast_search_option_create(apr_pool_t *pool)
{
    rast_search_option_t *options;

    options = (rast_search_option_t *)
        apr_palloc(pool, sizeof(rast_search_option_t));
    options->start_no = 0;
    options->num_items = RAST_RESULT_ALL_ITEMS;
    options->need_summary = 0;
    options->summary_nchars = 100;
    options->sort_method = RAST_SORT_METHOD_SCORE;
    options->sort_order = RAST_SORT_ORDER_DEFAULT;
    options->sort_property = NULL;
    options->score_method = RAST_SCORE_METHOD_TFIDF;
    options->properties = NULL;
    options->num_properties = 0;
    options->all_num_docs = RAST_CALC_SCORE_STANDALONE;
    options->terms = NULL;
    options->num_terms = 0;
    return options;
}

/* vim: set filetype=c sw=4 expandtab : */
