# Copyright (C) 2005  Network Applied Communication Laboratory Co., Ltd.
#
# This file is part of Rast.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA
#
# Linking the Rast statically or dynamically with other modules is
# making a combined work based on the Rast.  Thus, the terms and
# conditions of the GNU General Public License cover the whole
# combination.
#
# As a special exception, the copyright holders of the Rast give
# you permission to link the Rast with independent modules that
# communicate with the Rast solely through the the Apache Portable
# Runtime interface, regardless of the license terms of these
# independent modules, and to copy and distribute the resulting
# combined work under terms of your choice, provided that every
# copy of the combined work is accompanied by a complete copy of
# the source code of the Rast (the version of the Rast used to
# produce the combined work), being distributed under the terms of
# the GNU General Public License plus this exception.  An
# independent module is a module which is not derived from or based
# on the Rast.
#
# Note that people who make modified versions of the Rast are not
# obligated to grant this special exception for their modified
# versions; it is their choice whether to do so.  The GNU General
# Public License gives permission to release a modified version
# without this exception; this exception also makes it possible to
# release a modified version which carries forward this exception.

# -*- mode: Ruby; coding: euc-japan; -*-

require "test/unit"

require "rast_test"

module Rast
  class Encoding
    class MeCabEucJpTest < Test::Unit::TestCase
      def setup
        @encoding = Encoding["mecab_euc_jp"]
      end

      def test_register_tokenize
        result = []
        @encoding.register_tokenize("ruby is great.") do |ngram, pos, complete|
          result.push([ngram, pos, complete])
        end
        assert_equal(["ruby", 0, true], result[0])
        assert_equal([" ", 4, true], result[1])
        assert_equal(["is", 5, true], result[2])
        assert_equal([" ", 7, true], result[3])
        assert_equal(["great", 8, true], result[4])
        assert_equal([".", 13, true], result[5])
        assert_equal(6, result.length)

        result = []
        @encoding.register_tokenize("") do
          |ngram, pos, complete|
          result.push([ngram, pos, complete])
        end
        assert_equal(["", 0, true], result[0])
        assert_equal(["", 2, true], result[1])
        assert_equal(2, result.length)
      end
      
      def test_normalize_text
        assert_equal(" abc ", @encoding.normalize_text("  abc  "))
        assert_equal(" abc abc", @encoding.normalize_text(" abc\nabc"))
        assert_equal("a b c d e ",
                     @encoding.normalize_text("a\n \t b\nc\r\rd \ne "))

        s = @encoding.normalize_text("£")
        assert_equal("012ABC", s)
        s = @encoding.normalize_text("")
        assert_equal("", s)
        s = @encoding.normalize_text("")
        assert_equal("", s)
        s = @encoding.normalize_text("Î")
        assert_equal("ĥƥ", s)
        s = @encoding.normalize_text("Î")
        assert_equal("ĥƥ", s)
        s = @encoding.normalize_text("ގގގގ")
        assert_equal("", s)
        s = @encoding.normalize_text("ގގގÎގĎ")
        assert_equal("¥ťǥ", s)
        s = @encoding.normalize_text("ʎߎˎߎ̎ߎ͎ߎΎ")
        assert_equal("ѥԥץڥ", s)
        s = @encoding.normalize_text("")
        assert_equal("", s)
      end

      def test_normalize_chars
        s = @encoding.normalize_chars("ABC")
        assert_equal("abc", s)
      end
    end
  end
end
