# Copyright (C) 2005  Network Applied Communication Laboratory Co., Ltd.
#
# This file is part of Rast.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA
#
# Linking the Rast statically or dynamically with other modules is
# making a combined work based on the Rast.  Thus, the terms and
# conditions of the GNU General Public License cover the whole
# combination.
#
# As a special exception, the copyright holders of the Rast give
# you permission to link the Rast with independent modules that
# communicate with the Rast solely through the the Apache Portable
# Runtime interface, regardless of the license terms of these
# independent modules, and to copy and distribute the resulting
# combined work under terms of your choice, provided that every
# copy of the combined work is accompanied by a complete copy of
# the source code of the Rast (the version of the Rast used to
# produce the combined work), being distributed under the terms of
# the GNU General Public License plus this exception.  An
# independent module is a module which is not derived from or based
# on the Rast.
#
# Note that people who make modified versions of the Rast are not
# obligated to grant this special exception for their modified
# versions; it is their choice whether to do so.  The GNU General
# Public License gives permission to release a modified version
# without this exception; this exception also makes it possible to
# release a modified version which carries forward this exception.

require "tmpdir"
require "fileutils"

module TestUtility
  module_function

  def mkdtemp(prefix, mode = 0700)
    retry_count = 0
    begin
      dir = File.join(Dir.tmpdir, 
                      "#{prefix}-#{$$}.#{rand(10000)}")
      Dir.mkdir(dir, mode)
      return dir
    rescue Errno::EEXIST
      if retry_count < 3
        retry_count += 1
        retry
      else
        raise "can't create #{dir}"
      end
    end
  end

  def rm_rf(filename)
    count = 0
    begin
      FileUtils.rm_rf(filename)
    rescue Errno::ENOTEMPTY
      if count >= 3
        raise
      end
      count += 1
      retry
    end
  end
end
